# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ....core.api_error import ApiError
from ....core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ....core.http_response import AsyncHttpResponse, HttpResponse
from ....core.jsonable_encoder import jsonable_encoder
from ....core.parse_error import ParsingError
from ....core.request_options import RequestOptions
from ....core.unchecked_base_model import construct_type
from ....errors.unprocessable_entity_error import UnprocessableEntityError
from ....types.get_tool_executions_page_response_model import GetToolExecutionsPageResponseModel
from pydantic import ValidationError


class RawExecutionsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get(
        self,
        tool_id: str,
        *,
        cursor: typing.Optional[str] = None,
        page_size: typing.Optional[int] = None,
        is_error: typing.Optional[bool] = None,
        agent_id: typing.Optional[str] = None,
        branch_id: typing.Optional[str] = None,
        start_time: typing.Optional[float] = None,
        end_time: typing.Optional[float] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[GetToolExecutionsPageResponseModel]:
        """
        Get paginated list of tool executions for a specific tool.

        Parameters
        ----------
        tool_id : str
            ID of the requested tool.

        cursor : typing.Optional[str]
            Used for fetching next page. Cursor is returned in the response.

        page_size : typing.Optional[int]
            How many documents to return at maximum. Can not exceed 100, defaults to 30.

        is_error : typing.Optional[bool]
            Filter by error status. If not provided, returns all executions.

        agent_id : typing.Optional[str]
            Filter by agent ID.

        branch_id : typing.Optional[str]
            Filter by agent branch ID.

        start_time : typing.Optional[float]
            Filter executions from this Unix timestamp (inclusive).

        end_time : typing.Optional[float]
            Filter executions until this Unix timestamp (inclusive).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[GetToolExecutionsPageResponseModel]
            Successful Response
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/convai/tools/{jsonable_encoder(tool_id)}/executions",
            method="GET",
            params={
                "cursor": cursor,
                "page_size": page_size,
                "is_error": is_error,
                "agent_id": agent_id,
                "branch_id": branch_id,
                "start_time": start_time,
                "end_time": end_time,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetToolExecutionsPageResponseModel,
                    construct_type(
                        type_=GetToolExecutionsPageResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawExecutionsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get(
        self,
        tool_id: str,
        *,
        cursor: typing.Optional[str] = None,
        page_size: typing.Optional[int] = None,
        is_error: typing.Optional[bool] = None,
        agent_id: typing.Optional[str] = None,
        branch_id: typing.Optional[str] = None,
        start_time: typing.Optional[float] = None,
        end_time: typing.Optional[float] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[GetToolExecutionsPageResponseModel]:
        """
        Get paginated list of tool executions for a specific tool.

        Parameters
        ----------
        tool_id : str
            ID of the requested tool.

        cursor : typing.Optional[str]
            Used for fetching next page. Cursor is returned in the response.

        page_size : typing.Optional[int]
            How many documents to return at maximum. Can not exceed 100, defaults to 30.

        is_error : typing.Optional[bool]
            Filter by error status. If not provided, returns all executions.

        agent_id : typing.Optional[str]
            Filter by agent ID.

        branch_id : typing.Optional[str]
            Filter by agent branch ID.

        start_time : typing.Optional[float]
            Filter executions from this Unix timestamp (inclusive).

        end_time : typing.Optional[float]
            Filter executions until this Unix timestamp (inclusive).

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[GetToolExecutionsPageResponseModel]
            Successful Response
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/convai/tools/{jsonable_encoder(tool_id)}/executions",
            method="GET",
            params={
                "cursor": cursor,
                "page_size": page_size,
                "is_error": is_error,
                "agent_id": agent_id,
                "branch_id": branch_id,
                "start_time": start_time,
                "end_time": end_time,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    GetToolExecutionsPageResponseModel,
                    construct_type(
                        type_=GetToolExecutionsPageResponseModel,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        except ValidationError as e:
            raise ParsingError(
                status_code=_response.status_code, headers=dict(_response.headers), body=_response.json(), cause=e
            )
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)
